@@ -15,5 +15,13 @@ my $printer_usb = Printer::ESCPOS->new(
     productId  => 0x0006,
     endPoint   => 0x01
 );
+$printer_usb->printer->init();
+
+$printer_usb->printer->justify("left");
+$printer_usb->printer->qr("WIFI:T:WPA;S:CoreBPM Guest;P:CoreBPM.2016;;",'L',4,0);
+$printer_usb->printer->justify("right");
 $printer_usb->printer->qr("Don't Panic");
+
+$printer_usb->printer->lf();
+
 $printer_usb->printer->print();
