@@ -13,7 +13,7 @@ package Printer::ESCPOS;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '1.001'; # VERSION
+our $VERSION = '1.002'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -167,7 +167,7 @@ Printer::ESCPOS - Interface for all thermal, dot-matrix and other receipt printe
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 SYNOPSIS
 
@@ -208,7 +208,7 @@ For USB Printers L<Printer::ESCPOS> uses a default I<endPoint> of 0x01 and a def
  
      $device->printer->qr("Don't Panic!"); # Print a QR Code
  
-     $device->printer->printAreaWidth( nL => 0, nH => 1);
+     $device->printer->printAreaWidth(5000);
      $device->printer->text("Print Area Width Modified\n");
      $device->printer->printAreaWidth(); # Reset to default
      $device->printer->text("print area width reset\n");
@@ -242,7 +242,7 @@ you have configured your printer
  
      # These commands won't actually send anything to the printer but will store all the
      # merged data including control codes to module buffer.
-     $device->printer->printAreaWidth( nL => 0, nH => 1);
+     $device->printer->printAreaWidth(7000);
      $device->printer->text("Print Area Width Modified\n");
      $device->printer->printAreaWidth(); # Reset to default
      $device->printer->text("print area width reset\n");
